/* WGetUpdate.cmd: WGet Symantec NortonAV update

    Copyright (c) 2002 Steven Levine and Associates, Inc.

   This program is free software licensed under the terms of the GNU
   General Public License.  The GPL Software License can be found in
   gnugpl2.txt or at http://www.gnu.org/licenses/licenses.html#GPL

    Revisions	27 Feb 02 SHL - Release version for Mr. KIA

*/

signal on Error
signal on FAILURE name Error
signal on Halt
signal on NOTREADY name Error
signal on NOVALUE name Error
signal on SYNTAX name Error

call Initialize

szHost = 'ftp://ftp.symantec.com/public/english_us_canada/antivirus_definitions/norton_antivirus/'
szDnldDir = 'd:\NavOS2\Download'
szIncomingDir = 'd:\NavOS2\Common\Shared\VirusDef\Incoming'

cDays = 6

Main:

  parse arg szArg

  szDate = ''

  do while szArg \= ''

    parse var szArg sz szArg

    sz = translate(sz)
    c = length(sz)

    select
    when sz = '?' then
      call UsageHelp
    otherwise
      if \ datatype(sz, 'N') | length(sz) \= 4 then
	call Usage 'Expected MMDD'
      szDate = sz
    end /* select */
  end /* while */

  if szDate = '' then do
    szDate = date('S')
    /* Parse date */
    nMM = substr(szDate, 5, 2)
    nDD = substr(szDate, 7, 2)
  end
  else do
    nMM = substr(szDate, 1, 2)
    nDD = substr(szDate, 3, 2)
  end

  nMM = right('0' || nMM, 2)
  nDD = right('0' || nDD, 2)
  szMMDD = nMM || nDD

  call directory szDnldDir

  /* Find newest version */
  fGotNew = 0
  do cDays
    /* Form file name */
    szFile = szMMDD || 'o32.zip'
    if stream(szFile, 'C', 'QUERY EXISTS') \= '' then do
      '@dir'
      say
      if fGotNew then do
	say 'Fetched new' szFile
	'unzip -t' szFile
	if RC \= 0 then do
	  say 'unzip -t reported error' RC
	  call Beep 200, 500
	  'pause'
	end
	/* Unzip local copy */
	'unzip -jo' szFile '-d' szIncomingDir
	if RC \= 0 then do
	  say 'unzip -jo reported error' RC
	  call Beep 200, 500
	  'pause'
	end
      end
      else
	say 'Already have' szFile
      say 'Exiting in 5 seconds'
      call SysSleep 5
      '@exit'
      exit
    end
    say 'Trying' szFile '...'
    szURL = szHost || szFile
    signal off Error
    'wget' szURL
    signal on Error
    say 'wget RC=' RC
    say
    if RC = 0 then
      fGotNew = 1
    else do
      nDD = nDD - 1
      if nDD = 0 then do
	nMM = nMM - 1
	if nMM = 0 then do
	  nMM = 12
	end
	if nMM = 4 | nMM = 6 | nMM = 11 then
	  nDD = 30
	else if nMM = 2 then
	  nDD = 28			/* fixme for leap somewhen */
	else
	  nDD = 31
      end
      nDD = right('0' || nDD, 2)
      nMM = right('0' || nMM, 2)
      szMMDD = nMM || nDD
    end
  end /* forever */

  exit

/* end main */

/*=== Initialize: Intialize globals ===*/

Initialize:

  call LoadFuncs

  /* Set Gbl.szCmdName */
  parse source . . Gbl.szCmdName
  Gbl.szCmdName = filespec('N', Gbl.szCmdName)
  c = pos('.', Gbl.szCmdName)
  if c > 1 then
    Gbl.szCmdName = substr(Gbl.szCmdName, 1, c - 1)

  return

/* end Initialize */

/*=== Usage(szMsg): ... ===*/

Usage:
  parse arg szMsg
  say szMsg
  say 'Usage:' Gbl.szCmdName '[mmdd]'
  exit 255

/* end Usage */

/*=== Usage(): Display help ===*/

UsageHelp:
  say
  say 'Usage:' Gbl.szCmdName '[mmdd]'
  say
  say ' mmdd   Start search at this date (default is today)'
  say
  say ' Search starts on selected date and continues back for 6 days'
  say ' or until an existing signature file is found'

  exit 255

/* end UsageHelp */

/*========================================================================== */
/*=== Standard functions - Delete unused - Move modified above this mark === */
/*========================================================================== */

/*=== Error: Trap ERROR, FAILURE etc. - returns szCondition or exits ===*/

Error:
  say
  parse source . . szThisCmd
  say condition('C') 'signaled at' SIGL 'of' szThisCmd
  drop szThisCmd
  say 'Source =' sourceline(SIGL)
  call SysSleep 2
  if condition('I') == 'CALL' then do
    szCondition = condition('C')
    say 'Returning'
    return
  end
  else do
    trace '?A'
    say 'Exiting'
    call SysSleep 2
    exit 255
  end

/* end Error */

/*=== Fatal: Report fatal error and exit ===*/

Fatal:
  parse arg szMsg
  say
  say Gbl.szCmdName':' szMsg

  exit 254

/* end Fatal */

/*=== Halt(): Trap HALT condition - returns szCondition or exits ===*/

Halt:
  say
  parse source . . szThisCmd
  say condition('C') 'signaled at' SIGL 'of' szThisCmd
  drop szThisCmd
  say 'Source = ' sourceline(SIGL)
  call SysSleep 2
  if condition('I') == 'CALL' then do
    szCondition = condition('C')
    say 'Returning'
    return
  end
  else do
   say 'Exiting'
   exit
  end

/* end Halt */

/*=== LoadFuncs: Load fuctions ===*/

LoadFuncs:
  /* Add all Rexx functions */
  if RxFuncQuery('SysLoadFuncs') then do
    call RxFuncAdd 'SysLoadFuncs', 'REXXUTIL', 'SysLoadFuncs'
    if RESULT then do
      say 'Cannot load SysLoadFuncs'
      exit
    end
    call SysLoadFuncs
  end /* end do */

  return

/* end LoadFuncs */

/* The end */
